.. tsfm documentation master file, created by
   sphinx-quickstart on Thu Aug 31 15:30:57 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tsfm's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Introduction.rst
   Installation.rst
   Tutorial.rst
   MolecularInformation.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
